@@ -10,7 +10,6 @@
 #define  _BUT_BUT_H_  1
 
 #include <wms.h>
-#include <wms/snd.h>
 #if  HAVE_SYS_SELECT_H
 #include <sys/select.h>
 #endif
@@ -295,8 +294,9 @@ void  butSet_delBut(ButSet *butset, But *but);
 
 
 /* From "ctext.c" */
+#ifdef  _WMS_SND_H_
 extern Snd  but_downSnd, but_upSnd;
-
+#endif  /* _WMS_SND_H_ */
 
 /**********************************************************************
  * Forward declarations
